Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetRootDir ¶
GetRootDir returns the root directory of the Git repository containing the given path. Returns an empty string if no Git repository is found.
func GetRootDirWD ¶
GetRootDirWD returns the root directory of the Git repository containing the current working directory. Returns an empty string if no Git repository is found.
func IsCurrentDirInGitRepo ¶
IsCurrentDirInGitRepo checks if the current working directory is within a Git repository.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.